@@ -156,6 +156,8 @@ import {
   WithStatement,
   YieldExpression,
   Param,
+  ExprOrSpread,
+  TsConstAssertion,
 } from "./types";
 
 export default class Visitor {
@@ -164,7 +166,7 @@ export default class Visitor {
       case "Module":
         return this.visitModule(n);
       case "Script":
-        return this.visitScript(n);
+        return this.visitScript(n)
     }
   }
 
@@ -364,12 +366,18 @@ export default class Visitor {
   }
 
   visitArrayElement(
-    e: Expression | SpreadElement | undefined
-  ): Expression | SpreadElement | undefined {
-    if (e && e.type === "SpreadElement") {
-      return this.visitSpreadElement(e);
+    e: ExprOrSpread | undefined
+  ): ExprOrSpread | undefined {
+    if (e) {
+      return this.visitExprOrSpread(e);
+    }
+  }
+
+  visitExprOrSpread(e: ExprOrSpread): ExprOrSpread {
+    return {
+      ...e,
+      expression: this.visitExpression(e.expression)
     }
-    return this.visitOptionalExpression(e as Expression | undefined);
   }
 
   visitSpreadElement(e: SpreadElement): SpreadElement {
@@ -1068,6 +1076,8 @@ export default class Visitor {
         return this.visitTsNonNullExpression(n);
       case "TsTypeAssertion":
         return this.visitTsTypeAssertion(n);
+      case "TsConstAssertion":
+        return this.visitTsConstAssertion(n);
       case "UnaryExpression":
         return this.visitUnaryExpression(n);
       case "UpdateExpression":
@@ -1125,6 +1135,12 @@ export default class Visitor {
     return n;
   }
 
+
+  visitTsConstAssertion(n: TsConstAssertion): Expression {
+    n.expression = this.visitExpression(n.expression);
+    return n;
+  }
+
   visitTsNonNullExpression(n: TsNonNullExpression): Expression {
     n.expression = this.visitExpression(n.expression);
     return n;
@@ -1650,7 +1666,7 @@ export default class Visitor {
   }
 
   visitObjectPattern(n: ObjectPattern): Pattern {
-    n.props = this.visitObjectPatternProperties(n.props || []);
+    n.properties = this.visitObjectPatternProperties(n.properties || []);
     n.typeAnnotation = this.visitTsTypeAnnotation(n.typeAnnotation);
     return n;
   }
